==> assertj-core-2.0.0-sources.jar: org/assertj/core/error/ShouldBeWithin.java <==
/**
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2015 the original author or authors.
 */
package org.assertj.core.error;

import java.util.Date;

/**
 * Creates an error message indicating that an assertion that verifies that a {@link Date} is within a year, month, day, ...
 * failed.
 * 
 * @author Joel Costigliola
 */
public class ShouldBeWithin extends BasicErrorMessageFactory {

  /**
   * Creates a new </code>{@link ShouldBeWithin}</code>.
   * @param actual the actual value in the failed assertion.
   * @param fieldDescription the fieldDescription of value : year, month, day, ...
   * @param fieldValue the field value used in the failed assertion to compare the actual date field value to.
   * @return the created {@code ErrorMessageFactory}.
   */
  public static ErrorMessageFactory shouldBeWithin(Date actual, String fieldDescription, int fieldValue) {
    return new ShouldBeWithin(actual, fieldDescription, fieldValue);
  }

  private ShouldBeWithin(Date actual, String fieldDescription, int fieldValue) {
    super("\nExpecting:\n <%s>\nto be on %s <%s>", actual, fieldDescription, fieldValue);
  }
}

==> assertj-core-3.0.0-sources.jar: org/assertj/core/error/ShouldBeWithin.java <==
/**
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2015 the original author or authors.
 */
package org.assertj.core.error;

import java.util.Date;

/**
 * Creates an error message indicating that an assertion that verifies that a {@link Date} is within a year, month, day, ...
 * failed.
 * 
 * @author Joel Costigliola
 */
public class ShouldBeWithin extends BasicErrorMessageFactory {

  /**
   * Creates a new </code>{@link ShouldBeWithin}</code>.
   * @param actual the actual value in the failed assertion.
   * @param fieldDescription the fieldDescription of value : year, month, day, ...
   * @param fieldValue the field value used in the failed assertion to compare the actual date field value to.
   * @return the created {@code ErrorMessageFactory}.
   */
  public static ErrorMessageFactory shouldBeWithin(Date actual, String fieldDescription, int fieldValue) {
    return new ShouldBeWithin(actual, fieldDescription, fieldValue);
  }

  private ShouldBeWithin(Date actual, String fieldDescription, int fieldValue) {
    super("%nExpecting:%n <%s>%nto be on %s <%s>", actual, fieldDescription, fieldValue);
  }
}
